@@ -14,9 +14,6 @@ class AudioStation:
         self._sid = self.session.sid
         self.base_url = self.session.base_url
 
-        if debug is True:
-            print('You are now logged in!')
-
     def logout(self):
         self.session.logout('AudioStation')
 
