@@ -11,7 +11,7 @@ from . import auth as syn
 
 class FileStation:
 
-    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=7, debug=True, otp_code=None):
+    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=7, debug=True, otp_code=None, interactive_output=True):
 
         self.session = syn.Authentication(ip_address, port, username, password, secure, cert_verify, dsm_version, debug, otp_code)
 
@@ -30,7 +30,7 @@ class FileStation:
         self._compress_taskid = ''
         self._compress_taskid_list = []
         self.request_data = self.session.request_data
-
+        
         self.session.login('FileStation')
         self.session.get_api_list('FileStation')
 
@@ -38,8 +38,7 @@ class FileStation:
         self._sid = self.session.sid
         self.base_url = self.session.base_url
 
-        if debug is True:
-            print('You are now logged in!')
+        self.interactive_output = interactive_output
 
     def logout(self):
         self.session.logout('FileStation')
@@ -168,10 +167,18 @@ class FileStation:
 
         response = self.request_data(api_name, api_path, req_param)
 
-        self._search_taskid = '"' + response['data']['taskid'] + '"'
+        taskid = response['data']['taskid']
+        self._search_taskid = '"{}"'.format(taskid)
         self._search_taskid_list.append('"' + response['data']['taskid'] + '"')
 
-        return 'You can now check the status of request with get_search_list() , your id is: ' + self._search_taskid
+        message = ('You can now check the status of request with '
+                   'get_search_list() , your id is: ' + self._search_taskid)
+        if self.interactive_output:
+            output = message
+        else:
+            output = {"message": message, "taskid": taskid}
+
+        return output
 
     def get_search_list(self, task_id=None, filetype=None, limit=None, sort_by=None, sort_direction=None,
                         offset=None, additional=None):
@@ -222,7 +229,7 @@ class FileStation:
         api_path = info['path']
         req_param = {'version': info['maxVersion'], 'method': 'stop', 'taskid': ''}
 
-        assert len(self._search_taskid_list) is not 0, 'Task list is empty' + str(self._search_taskid_list)
+        assert len(self._search_taskid_list), 'Task list is empty' + str(self._search_taskid_list)
 
         for task_id in self._search_taskid_list:
             req_param['taskid'] = task_id
@@ -377,12 +384,22 @@ class FileStation:
         else:
             return 'Enter a valid path'
 
-        response_id = '"' + self.request_data(api_name, api_path, req_param)['data']['taskid'] + '"'
+        taskid = self.request_data(api_name, api_path, req_param)['data']['taskid']
 
+        response_id = '"{}"'.format(taskid)
         self._dir_taskid = response_id
         self._dir_taskid_list.append(response_id)
 
-        return 'You can now check the status of request with get_dir_status() , your id is: ' + self._dir_taskid
+        message = ('You can now check the status of request '
+                   'with get_dir_status() , your id is: '
+                   + response_id)
+        if self.interactive_output:
+            output = message
+        else:
+            output = {"message": message, "taskid": taskid}
+
+        return output
+
 
     def stop_dir_size_calc(self, taskid=None):
         api_name = 'SYNO.FileStation.DirSize'
@@ -406,7 +423,7 @@ class FileStation:
         api_path = info['path']
         req_param = {'version': info['maxVersion'], 'method': 'status', 'taskid': taskid}
 
-        if taskid is None and self._dir_taskid is not '':
+        if taskid is None and self._dir_taskid != '':
             return 'Choose a taskid from this list: ' + str(self._dir_taskid)
 
         return self.request_data(api_name, api_path, req_param)
@@ -425,7 +442,14 @@ class FileStation:
         self._md5_calc_taskid = self.request_data(api_name, api_path, req_param)['data']['taskid']
         self._md5_calc_taskid_list.append(self._md5_calc_taskid)
 
-        return 'You can now check the status of request with get_md5_status() , your id is: ' + self._md5_calc_taskid
+        message = ('You can now check the status of request with '
+                   'get_md5_status() , your id is: ' + self._md5_calc_taskid)
+        if self.interactive_output:
+            output = message
+        else:
+            output = {"message": message, "taskid": self._md5_calc_taskid}
+
+        return output
 
     def get_md5_status(self, taskid=None):
         api_name = 'SYNO.FileStation.MD5'
@@ -433,7 +457,7 @@ class FileStation:
         api_path = info['path']
         req_param = {'version': info['maxVersion'], 'method': 'status'}
 
-        if taskid is None and self._md5_calc_taskid is not '':
+        if taskid is None and self._md5_calc_taskid != '':
             req_param['taskid'] = '"{taskid}"'.format(taskid=self._md5_calc_taskid)
         elif taskid is not None:
             req_param['taskid'] = '"{taskid}"'.format(taskid=taskid)
@@ -482,9 +506,30 @@ class FileStation:
         info = self.file_station_list[api_name]
         api_path = info['path']
         filename = os.path.basename(file_path)
+        filepath = os.path.dirname(file_path)
 
         session = requests.session()
 
+        url = ('%s%s' % (self.base_url, api_path)) + '?api=%s&version=%s&method=upload&_sid=%s' % (
+            api_name, info['minVersion'], self._sid)
+
+        args = {
+            'path': dest_path,
+            'create_parents': str(create_parents).lower(),
+            'overwrite': str(overwrite).lower(),
+        }
+
+        encode_file = open(file_path, 'rb')
+
+        r = session.post(url, data=args, files={'from_field_name': encode_file}, verify=verify)
+
+        if r.ok:
+            print('completed')
+            print(r.text)
+        else:
+            print('???')
+
+        '''
         with open(file_path, 'rb') as payload:
             url = ('%s%s' % (self.base_url, api_path)) + '?api=%s&version=%s&method=upload&_sid=%s' % (
                 api_name, info['minVersion'], self._sid)
@@ -499,10 +544,10 @@ class FileStation:
 
             r = session.post(url, data=args, files=files, verify=verify)
 
-            if r.status_code is 200 and r.json()['success']:
+            if r.status_code == 200 and r.json()['success']:
                 return 'Upload Complete'
             else:
-                return r.status_code, r.json()
+                return r.status_code, r.json()'''
 
     def get_shared_link_info(self, link_id=None):
         api_name = 'SYNO.FileStation.Sharing'
@@ -532,7 +577,7 @@ class FileStation:
         return self.request_data(api_name, api_path, req_param)
 
     def create_sharing_link(self, path=None, password=None, date_expired=None,
-                            date_available=None):
+                            date_available=None, expire_times=0):
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -570,7 +615,7 @@ class FileStation:
         return self.request_data(api_name, api_path, req_param)
 
     def edit_shared_link(self, link_id=None, password=None, date_expired=None,
-                         date_available=None):
+                         date_available=None, expire_times=0):
         api_name = 'SYNO.FileStation.Sharing'
         info = self.file_station_list[api_name]
         api_path = info['path']
@@ -710,8 +755,16 @@ class FileStation:
         self._copy_move_taskid = self.request_data(api_name, api_path, req_param)['data']['taskid']
         self._dir_taskid_list.append(self._copy_move_taskid)
 
-        return 'You can now check the status of request with get_copy_move_status() , ' \
-               'your id is: ' + self._copy_move_taskid
+        message = ('You can now check the status of request with '
+                   'get_copy_move_status() , your id is: '
+                   + self._copy_move_taskid)
+        if self.interactive_output:
+            output = message
+        else:
+            output = {"message": message, "taskid": self._copy_move_taskid}
+
+        return output
+
 
     def get_copy_move_status(self, taskid=None):
         api_name = 'SYNO.FileStation.CopyMove'
@@ -766,8 +819,16 @@ class FileStation:
         self._delete_taskid = self.request_data(api_name, api_path, req_param)['data']['taskid']
         self._delete_taskid_list.append(self._delete_taskid)
 
-        return 'You can now check the status of request with get_delete_status() , ' \
-               'task id is: ' + self._delete_taskid
+        message = ('You can now check the status of request with '
+                   'get_delete_status() , task id is: '
+                   + self._delete_taskid)
+        if self.interactive_output:
+            output = message
+        else:
+            output = {"message": message, "taskid": self._delete_taskid}
+
+        return output
+
 
     def get_delete_status(self, taskid=None):
         api_name = 'SYNO.FileStation.Delete'
@@ -843,11 +904,17 @@ class FileStation:
             return 'Enter a valid dest_folder_path'
 
         self._extract_taskid = self.request_data(api_name, api_path, req_param)['data']['taskid']
-
         self._extract_taskid_list.append(self._extract_taskid)
 
-        return 'You can now check the status of request with get_extract_status() , ' \
-               'your id is: ' + self._extract_taskid
+        message = ('You can now check the status of request with '
+                   'get_extract_status() , your id is: '
+                   + self._extract_taskid)
+        if self.interactive_output:
+            output = message
+        else:
+            output = {"message": message, "taskid": self._extract_taskid}
+
+        return output
 
     def get_extract_status(self, taskid=None):
         api_name = 'SYNO.FileStation.Extract'
@@ -929,8 +996,16 @@ class FileStation:
 
         self._compress_taskid = self.request_data(api_name, api_path, req_param)['data']['taskid']
 
-        return 'You can now check the status of request with get_compress_status() , ' \
-               'your id is: ' + self._compress_taskid
+        message =('You can now check the status of request with '
+                  'get_compress_status() , your id is: '
+                  + self._compress_taskid)
+        if self.interactive_output:
+            output = message
+        else:
+            output = {"message": message, "taskid": self._compress_taskid}
+
+        return output
+
 
     def get_compress_status(self, taskid=None):
         api_name = 'SYNO.FileStation.Compress'
@@ -997,14 +1072,14 @@ class FileStation:
             return 'Enter a valid mode (open / download)'
 
         if mode == r'open':
-            with session.get(url, stream=True,verify=verify) as r:
+            with session.get(url, stream=True, verify=verify) as r:
                 r.raise_for_status()
                 for chunk in r.iter_content(chunk_size=chunk_size):
                     if chunk:  # filter out keep-alive new chunks
                         sys.stdout.buffer.write(chunk)
 
         if mode == r'download':
-            with session.get(url, stream=True,verify=verify) as r:
+            with session.get(url, stream=True, verify=verify) as r:
                 r.raise_for_status()
                 if not os.path.isdir(dest_path):
                     os.makedirs(dest_path)
